@@ -4,6 +4,7 @@ import subprocess
 import sys
 from pathlib import Path
 from typing import Optional
+
 import rich_click as click
 from bx_py_utils.path import assert_is_dir, assert_is_file
 from rich import print  # noqa
@@ -12,7 +13,7 @@ from rich_click import RichGroup
 import manageprojects
 from manageprojects import __version__, constants
 from manageprojects.constants import (
-    FORMAT_PY_FILE_DARKER_PREFIXES,
+    FORMAT_PY_FILE_DARKER_PRE_FIXES,
     FORMAT_PY_FILE_DEFAULT_MAX_LINE_LENGTH,
     FORMAT_PY_FILE_DEFAULT_MIN_PYTON_VERSION,
 )
@@ -114,13 +115,15 @@ def update():
     """
     Update "requirements*.txt" dependencies files
     """
+    verbose_check_call('pip', 'install', '-U', 'pip')
+    verbose_check_call('pip', 'install', '-U', 'pip-tools')
+
     extra_env = dict(
         CUSTOM_COMPILE_COMMAND='./cli.py update',
     )
-    bin_path = Path(sys.executable).parent
 
     pip_compile_base = [
-        bin_path / 'pip-compile',
+        'pip-compile',
         '--verbose',
         '--allow-unsafe',  # https://pip-tools.readthedocs.io/en/latest/#deprecations
         '--resolver=backtracking',  # https://pip-tools.readthedocs.io/en/latest/#deprecations
@@ -434,7 +437,7 @@ def publish():
     """
     Build and upload this project to PyPi
     """
-    _run_unittest_cli(verbose=False)  # Don't publish a broken state
+    _run_unittest_cli(verbose=False, exit_after_run=False)  # Don't publish a broken state
 
     git = Git(cwd=PACKAGE_ROOT, detect_root=True)
 
@@ -494,7 +497,38 @@ def check_code_style(color: bool = True, verbose: bool = False):
 cli.add_command(check_code_style)
 
 
-def _run_unittest_cli(extra_env=None, verbose=True):
+@click.command()
+def update_test_snapshot_files():
+    """
+    Update all test snapshot files (by remove and recreate all snapshot files)
+    """
+
+    def iter_snapshot_files():
+        yield from PACKAGE_ROOT.rglob('*.snapshot.*')
+
+    removed_file_count = 0
+    for item in iter_snapshot_files():
+        item.unlink()
+        removed_file_count += 1
+    print(f'{removed_file_count} test snapshot files removed... run tests...')
+
+    # Just recreate them by running tests:
+    _run_unittest_cli(
+        extra_env=dict(
+            RAISE_SNAPSHOT_ERRORS='0',  # Recreate snapshot files without error
+        ),
+        verbose=False,
+        exit_after_run=False,
+    )
+
+    new_files = len(list(iter_snapshot_files()))
+    print(f'{new_files} test snapshot files created, ok.\n')
+
+
+cli.add_command(update_test_snapshot_files)
+
+
+def _run_unittest_cli(extra_env=None, verbose=True, exit_after_run=True):
     """
     Call the origin unittest CLI and pass all args to it.
     """
@@ -523,48 +557,38 @@ def _run_unittest_cli(extra_env=None, verbose=True):
         timeout=15 * 60,
         extra_env=extra_env,
     )
+    if exit_after_run:
+        sys.exit(0)
 
 
-@click.command()  # Dummy command, to add "tests" into help page ;)
+cli.add_command(update_test_snapshot_files)
+
+
+@click.command()  # Dummy command
 def test():
     """
     Run unittests
     """
     _run_unittest_cli()
-    sys.exit(0)
 
 
 cli.add_command(test)
 
 
-@click.command()
-def update_test_snapshot_files():
+def _run_tox():
+    verbose_check_call(sys.executable, '-m', 'tox', *sys.argv[2:])
+    sys.exit(0)
+
+
+@click.command()  # Dummy "tox" command
+def tox():
     """
-    Update all test snapshot files (by remove and recreate all snapshot files)
+    Run tox
     """
-
-    def iter_snapshot_files():
-        yield from PACKAGE_ROOT.rglob('*.snapshot.*')
-
-    removed_file_count = 0
-    for item in iter_snapshot_files():
-        item.unlink()
-        removed_file_count += 1
-    print(f'{removed_file_count} test snapshot files removed... run tests...')
-
-    # Just recreate them by running tests:
-    _run_unittest_cli(
-        extra_env=dict(
-            RAISE_SNAPSHOT_ERRORS='0',  # Recreate snapshot files without error
-        ),
-        verbose=False,
-    )
-
-    new_files = len(list(iter_snapshot_files()))
-    print(f'{new_files} test snapshot files created, ok.\n')
+    _run_tox()
 
 
-cli.add_command(update_test_snapshot_files)
+cli.add_command(tox)
 
 
 @click.command()
@@ -584,7 +608,7 @@ cli.add_command(update_test_snapshot_files)
 )
 @click.option(
     '--darker-prefixes',
-    default=FORMAT_PY_FILE_DARKER_PREFIXES,
+    default=FORMAT_PY_FILE_DARKER_PRE_FIXES,
     show_default=True,
     help='Apply prefixes via autopep8 before calling darker.',
 )
@@ -613,13 +637,27 @@ def format_file(
 cli.add_command(format_file)
 
 
+@click.command()
+def version():
+    """Print version and exit"""
+    # Pseudo command, because the version always printed on every CLI call ;)
+    sys.exit(0)
+
+
+cli.add_command(version)
+
+
 def main():
     print_version(manageprojects)
 
-    if len(sys.argv) >= 2 and sys.argv[1] == 'test':
-        # Just use the CLI from unittest with all available options and origin --help output ;)
-        _run_unittest_cli()
-    else:
-        # Execute Click CLI:
-        cli.name = './cli.py'
-        cli()
+    if len(sys.argv) >= 2:
+        # Check if we just pass a command call
+        command = sys.argv[1]
+        if command == 'test':
+            _run_unittest_cli()
+        elif command == 'tox':
+            _run_tox()
+
+    # Execute Click CLI:
+    cli.name = './cli.py'
+    cli()
