@@ -8,11 +8,10 @@ from unittest import TestCase
 from bx_py_utils.test_utils.datetime import parse_dt
 from bx_py_utils.test_utils.snapshot import assert_text_snapshot
 
-from manageprojects import __version__
-from manageprojects.cli.cli_app import PACKAGE_ROOT, version
+from manageprojects.cli.cli_app import PACKAGE_ROOT
 from manageprojects.git import Git
-from manageprojects.test_utils.click_cli_utils import invoke_click
 from manageprojects.test_utils.git_utils import init_git
+from manageprojects.test_utils.logs import AssertLogs
 from manageprojects.utilities.temp_path import TemporaryDirectory
 
 
@@ -54,9 +53,6 @@ class GitTestCase(TestCase):
         git_hash = git.get_current_hash(verbose=False)
         self.assertEqual(len(git_hash), 7, f'Wrong: {git_hash!r}')
 
-        output = invoke_click(version, strip=False)
-        self.assertEqual(output, f'manageprojects v{__version__} {git_hash}\n')
-
         commit_date = git.get_commit_date(verbose=False)
         self.assertIsInstance(commit_date, datetime.datetime)
         self.assertGreater(commit_date, parse_dt('2023-01-01T00:00:00+0000'))
@@ -227,3 +223,25 @@ class GitTestCase(TestCase):
 
             status = git.status(verbose=False)
             self.assertEqual(status, [])
+
+    def test_branch_names(self):
+        with TemporaryDirectory(prefix='test_branch_names_') as temp_path:
+            Path(temp_path, 'foo.txt').touch()
+            git, first_hash = init_git(temp_path)
+
+            with AssertLogs(self, loggers=('manageprojects',)) as logs:
+                branch_names = git.get_branch_names()
+                self.assertEqual(branch_names, ['main'])
+            logs.assert_in('Git branches: main')
+
+            git.git_verbose_check_call('checkout', '-b', 'foobar')
+
+            with AssertLogs(self, loggers=('manageprojects',)) as logs:
+                branch_names = git.get_branch_names()
+                self.assertEqual(branch_names, ['foobar', 'main'])
+            logs.assert_in('Git branches: foobar, main')
+
+            with AssertLogs(self, loggers=('manageprojects',)) as logs:
+                main_branch_name = git.get_main_branch_name()
+                self.assertEqual(main_branch_name, 'main')
+            logs.assert_in('Git main branch: "main"')
